unit DecBinHex;

interface

uses
  SysUtils, Classes;

type
  TDecBinHex = class(TComponent)
  private
    { Private declarations }
    function Potencia(Base,Exponente:Integer):LongInt;
    function PotenciaNegativa(Base,Exponente:Integer):Extended;
    procedure VerCreado;
  protected
    { Protected declarations }
  public
    { Public declarations }
    procedure Create(); overload;
  published
    { Published declarations }
    {------------------PASAJES------------------}
    function DecToBin(Dec:String):String;
    function DecToHex(Dec:String):String;
    function BinToDec(Bin:String):String;
    function BinToHex(Bin:String):String;
    function HexToDec(Hex:String):String;
    function HexToBin(Hex:String):String;
    {-------------------SUMA--------------------}
    function AddToDec(Num1,Num2:String; Tipo1,Tipo2:Char):String;
    function AddToBin(Num1,Num2:String; Tipo1,Tipo2:Char):String;
    function AddToHex(Num1,Num2:String; Tipo1,Tipo2:Char):String;
    {------------------RESTA--------------------}
    function SubToDec(Num1,Num2:String; Tipo1,Tipo2:Char):String;
    function SubToBin(Num1,Num2:String; Tipo1,Tipo2:Char):String;
    function SubToHex(Num1,Num2:String; Tipo1,Tipo2:Char):String;
    {-------------MULTIPLICACION----------------}
    function MultToDec(Num1,Num2:String; Tipo1,Tipo2:Char):String;
    function MultToBin(Num1,Num2:String; Tipo1,Tipo2:Char):String;
    function MultToHex(Num1,Num2:String; Tipo1,Tipo2:Char):String;
    {----------------DIVISION-------------------}
    function DivToDec(Num1,Num2:String; Tipo1,Tipo2:Char):String;
    function DivToBin(Num1,Num2:String; Tipo1,Tipo2:Char):String;
    function DivToHex(Num1,Num2:String; Tipo1,Tipo2:Char):String;
    {---------------MANIPULACION----------------}
    function TipoNumero(Num:String):String;
    procedure SetBits(Bits:Integer =32);
    procedure Create(Bits:Integer); overload;
  end;

procedure Register;

implementation

type
  TTipoNumero = (Decimal, Binario, Hexadecimal);

const
  OTROS = [#0..#31,'.']; //Sin espacios
  DEC = ['0'..'9']+OTROS;
  BIN = ['0','1']+OTROS;
  HEX = ['0'..'9','A'..'F','a'..'f']+OTROS;
  SeparadorDecimal = '.';

var
  FVeces:Integer;
  FCreado:Boolean = False;

procedure Register;
begin
  RegisterComponents('Bruno', [TDecBinHex]);
end;

{-------DECLARADO AC PARA EVITAR ERRORES CON TTipoNumero---------}
{DEVUELVE TRUE SI EL TIPO INDICADO ES EL MISMO AL TIPO DEL NUMERO ENVIADO}
function EsTipoPedido(Num:String; Tipo:TTipoNumero):Boolean;
var
  I:Integer;
  Conj: set of char;
begin
  case Tipo of
    Decimal: Conj:=DEC;
    Binario: Conj:=BIN;
    Hexadecimal: Conj:=HEX;
  end;
  Result:=True;
  I:=1;
  while (Result) and (I <= Length(Num)) do begin
    Result:=Num[I] IN Conj;
    Inc(I);
  end;
end;

{---------------------------MANIPULACION--------------------------}
{---------------------------MANIPULACION--------------------------}
{---------------------------MANIPULACION--------------------------}

procedure TDecBinHex.VerCreado;
begin
  if NOT(FCreado) then begin
    raise Exception.Create('Debe crear el objeto antes de utilizarlo.');
    Exit;
  end;
end;

procedure TDecBinHex.Create;
begin
  FCreado:=True;
  SetBits(32);
end;

procedure TDecBinHex.Create(Bits:Integer);
begin
  FCreado:=True;
  SetBits(Bits);
end;

{Setea la cantidad de bits a usar (veces de los bucles) en los decimales}
procedure TDecBinHex.SetBits(Bits: Integer = 32);
begin
  VerCreado;
  FVeces:=Bits;
end;

{Simple funcin de potencia, para no usar la unit Math}
function TDecBinHex.Potencia(Base: Integer; Exponente: Integer):LongInt;
var
  I,N:LongInt;
begin
  if (Exponente=0) then
    Result:=1
  else begin
    N:=Base;
    for I := 2 to Exponente do
      N:=N*Base;
    Result:=N;
  end;
end;

{Para los decimales se usan exponentes negativos}
function TDecBinHex.PotenciaNegativa(Base: Integer; Exponente: Integer):Extended;
var
  Poten:LongInt;
begin
  Poten:=Potencia(Base,Exponente);
  if (Poten=0) then
    Result:=0
  else
    Result:=1/Potencia(Base,Exponente);
end;


{-----------------------PASAJES DE SISTEMAS-----------------------}
{-----------------------PASAJES DE SISTEMAS-----------------------}
{-----------------------PASAJES DE SISTEMAS-----------------------}


{----------------------Decimal a Binario--------------------------}
function TDecBinHex.DecToBin(Dec:String):String;
{---Funciona bien con COMA---}
var
  StrAux,Enteros,Decimales:String;
  I,NEnteros,Veces:Integer;
  NDecimales:Extended;
begin
  VerCreado;
  if (EsTipoPedido(Dec,Decimal)) then begin
    {Separo la parte entera de la decimal}
    Enteros:='';
    Decimales:='';
    I:=1;
    while NOT(Dec[I]=SeparadorDecimal) and (I<=Length(Dec)) do begin
      Enteros:=Enteros+Dec[I];
      Inc(I);
    end;
    if (Dec[I]=SeparadorDecimal) then begin
      Inc(I);
      while (I<=Length(Dec)) do begin
        Decimales:=Decimales+Dec[I];
        Inc(I);
      end;
    end;
    {Fin separacin}

    NEnteros:=StrToInt(Enteros);
    StrAux:='';
    Result:='';
    {Agregar los nmeros enteros}
    while (NEnteros <> 0) do begin
      StrAux:=StrAux+IntToStr(NEnteros MOD 2);
      NEnteros:=NEnteros DIV 2;
    end;
    for I := Length(StrAux) downto 1 do
      Result:=Result+StrAux[I];

    {Agregar los nmeros decimales}
    if (Length(Decimales)>0) then begin
      Veces:=0;
      Result:=Result+SeparadorDecimal;
      NDecimales:=StrToFloat('0'+SeparadorDecimal+Decimales);
      while (Veces<FVeces) and (BinToDec(Result)<>Dec) do begin
        NDecimales:=NDecimales*2;
        Result:=Result+FloatToStr(NDecimales)[1];
        if (NDecimales>=1) then
          NDecimales:=NDecimales-1;
        Inc(Veces);
      end;
    end;
  end
  else
    raise Exception.Create('Tipo soliciado: DECIMAL; Tipo recibido: '+TipoNumero(Dec));
end;

{----------------------Decimal a Hexadecimal----------------------}
function TDecBinHex.DecToHex(Dec:String):String;
{---Funciona bien con COMA---}
var
  I,NEnteros,Veces,NumTmp:Integer;
  StrAux,Enteros,Decimales:String;
  NDecimales:Extended;
begin
  VerCreado;
  if (EsTipoPedido(Dec,Decimal)) then begin
    {Separo la parte entera de la decimal}
    Enteros:='';
    Decimales:='';
    I:=1;
    while NOT(Dec[I]=SeparadorDecimal) and (I<=Length(Dec)) do begin
      Enteros:=Enteros+Dec[I];
      Inc(I);
    end;
    if (Dec[I]=SeparadorDecimal) then begin
      Inc(I);
      while (I<=Length(Dec)) do begin
        Decimales:=Decimales+Dec[I];
        Inc(I);
      end;
    end;
    {Fin separacin}

    StrAux:='';
    Result:='';
    {Agregar los nmeros enteros}
    NEnteros:=StrToInt(Enteros);
    StrAux:='';
    while (NEnteros <> 0) do begin
      NumTmp:=NEnteros MOD 16;
      if (NumTmp=10) then
        StrAux:=StrAux+'A'
      else
      if (NumTmp=11) then
        StrAux:=StrAux+'B'
      else
      if (NumTmp=12) then
        StrAux:=StrAux+'C'
      else
      if (NumTmp=13) then
        StrAux:=StrAux+'D'
      else
      if (NumTmp=14) then
        StrAux:=StrAux+'E'
      else
      if (NumTmp=15) then
        StrAux:=StrAux+'F'
      else
        StrAux:=StrAux+IntToStr(NumTmp);
      NEnteros:=NEnteros DIV 16;
    end;
    Result:='';
    for I := Length(StrAux) downto 1 do
      Result:=Result+StrAux[I];
    {Fin agregado enteros}

    {Agregar los decimales}
    if (Length(Decimales)>0) then begin
      Veces:=0;
      Result:=Result+SeparadorDecimal;
      NDecimales:=StrToFloat('0'+SeparadorDecimal+Decimales);
      while (Veces<FVeces) and (HexToDec(Result)<>Dec) do begin
        NDecimales:=NDecimales*16;
        if (NDecimales>=15) then
          Result:=Result+'F'
        else
          if (NDecimales>=14) then
            Result:=Result+'E'
        else
          if (NDecimales>=13) then
            Result:=Result+'D'
        else
          if (NDecimales>=12) then
            Result:=Result+'C'
        else
          if (NDecimales>=11) then
            Result:=Result+'B'
        else
          if (NDecimales>=10) then
            Result:=Result+'A'
        else
          Result:=Result+FloatToStr(NDecimales)[1];
        while (NDecimales>=1) do
          NDecimales:=NDecimales-1;
        Inc(Veces);
      end;
    end;
  end
  else
    raise Exception.Create('Tipo soliciado: DECIMAL; Tipo recibido: '+TipoNumero(Dec));
end;

{----------------------Binario a Decimal--------------------------}
function TDecBinHex.BinToDec(Bin:String):String;
{---Funciona bien con COMA---}
var
  StrAux,Enteros,Decimales:String;
  N,I:Integer;
  F:Extended;
begin
  VerCreado;
  if (EsTipoPedido(Bin,Binario)) then begin
    Enteros:='';
    Decimales:='';
    I:=1;
    while NOT(Bin[I]=SeparadorDecimal) and (I<=Length(Bin)) do begin
      Enteros:=Enteros+Bin[I];
      Inc(I);
    end;
    if (Bin[I]=SeparadorDecimal) then begin
      Inc(I);
      while (I<=Length(Bin)) do begin
        Decimales:=Decimales+Bin[I];
        Inc(I);
      end;
    end;
    {Fin separacin}

    StrAux:='';
    {Voltear el string Enteros y pasarlo a decimal}
    for I := Length(Enteros) downto 1 do
      StrAux:=StrAux+Enteros[I];
    N:=0;
    for I := 1 to Length(StrAux) do begin
      N:=N+(StrToInt(StrAux[I])*Potencia(2,I-1));
    end;
    Result:=IntToStr(N);
    {Pasar los decimales a decimal}
    if (Length(Decimales)>0) then begin
      F:=StrToFloat(Result);
      for I := 1 to Length(Decimales) do
        F:=F+(StrToInt(Decimales[I])*PotenciaNegativa(2,I));
      Result:=FloatToStr(F);
    end;
  end
  else
    raise Exception.Create('Tipo soliciado: BINARIO; Tipo recibido: '+TipoNumero(Bin));
end;

{----------------------Binario a Hexadecimal----------------------}
function TDecBinHex.BinToHex(Bin:String):String;
{---Funciona bien con COMA---}
begin
  VerCreado;
  if (EsTipoPedido(Bin,Binario)) then begin
    Bin:=BinToDec(Bin);
    Result:=DecToHex(Bin);
  end
  else
    raise Exception.Create('Tipo soliciado: BINARIO; Tipo recibido: '+TipoNumero(Bin));
end;

{----------------------Hexadecimal a Decimal----------------------}
function TDecBinHex.HexToDec(Hex:String):String;
{---Funciona bien con COMA---}
var
  StrAux,Enteros,Decimales:String;
  N,I,Posi:Integer;
  F:Extended;
begin
  VerCreado;
  if (EsTipoPedido(Hex,Hexadecimal)) then begin
    {Separo la parte entera de la decimal}
    Enteros:='';
    Decimales:='';
    I:=1;
    while NOT(Hex[I]=SeparadorDecimal) and (I<=Length(Hex)) do begin
      Enteros:=Enteros+Hex[I];
      Inc(I);
    end;
    if (Hex[I]=SeparadorDecimal) then begin
      Inc(I);
      while (I<=Length(Hex)) do begin
        Decimales:=Decimales+Hex[I];
        Inc(I);
      end;
    end;
    {Fin separacin}

    Result:='';
    StrAux:='';
    {Voltear el string y agregar enteros}
    for N := Length(Enteros) downto 1 do
      StrAux:=StrAux+Hex[N];
    N:=0;
    for I := 1 to Length(StrAux) do begin
      case StrAux[I] of
        'A': Posi:=10;
        'B': Posi:=11;
        'C': Posi:=12;
        'D': Posi:=13;
        'E': Posi:=14;
        'F': Posi:=15;
      else
        Posi:=StrToInt(StrAux[I]);
      end;
      N:=N+(Posi*Potencia(16,I-1));
    end;
    Result:=IntToStr(N);
    {Fin agregado enteros}

    {Agregar decimales}
    if (Length(Decimales)>0) then begin
      F:=StrToFloat(Result);
      for I := 1 to Length(Decimales) do begin
        case Decimales[I] of
          'A': Posi:=10;
          'B': Posi:=11;
          'C': Posi:=12;
          'D': Posi:=13;
          'E': Posi:=14;
          'F': Posi:=15;
        else
          Posi:=StrToInt(Decimales[I]);
        end;
        F:=F+(Posi*PotenciaNegativa(16,I));
      end;
      Result:=FloatToStr(F);
    end;
  end
  else
    raise Exception.Create('Tipo soliciado: HEXADECIMAL; Tipo recibido: '+TipoNumero(Hex));
end;

{----------------------Hexadecimal a Binario----------------------}
function TDecBinHex.HexToBin(Hex:String):String;
var
  Aux,Enteros,Decimales:String;
  I:Integer;
begin
  VerCreado;
  if (EsTipoPedido(Hex,Hexadecimal)) then begin
    Hex:=HexToDec(Hex);
    Aux:=DecToBin(Hex);
    Enteros:='';
    Decimales:='';
    I:=1;
    while (Aux[I]<>SeparadorDecimal) do begin
      Enteros:=Enteros+Aux[I];
      Inc(I);
    end;
    Inc(I);
    while (I<=Length(Aux)) do begin
      Decimales:=Decimales+Aux[I];
      Inc(I);
    end;
    {Completar enteros con 0 y completar decimales con 0}
    while (Length(Enteros) MOD 4 <> 0) do
      Enteros:='0'+Enteros;
    Result:=Enteros;
    if (Decimales<>'') then begin
      while (Length(Decimales) MOD 4 <> 0) do
        Decimales:=Decimales+'0';
      Result:=Result+'.'+Decimales;
    end;
  end
  else
    raise Exception.Create('Tipo soliciado: HEXADECIMAL; Tipo recibido: '+TipoNumero(Hex));
end;

{Devuelve en un string el tipo de dato del numero dado}
function TDecBinHex.TipoNumero(Num: string):String;
begin
  VerCreado;
  if (EsTipoPedido(Num,Decimal)) then
    Result:='Decimal'
  else
  if (EsTipoPedido(Num,Binario)) then
    Result:='Binario'
  else
  if (EsTipoPedido(Num,Hexadecimal)) then
    Result:='Hexadecimal'
  else
    Result:='DESCONOCIDO';
end;



{----------------------FUNCIONES MATEMATICAS----------------------}
{----------------------FUNCIONES MATEMATICAS----------------------}
{----------------------FUNCIONES MATEMATICAS----------------------}


{-------------------------------SUMA------------------------------}

{Recibe 2 numeros de cualquier tipo cada uno, los suma y los devuelve como DEC}
{En Tipo1 y Tipo2 debe recibir "D" para decimales, "B" para binarios y "H" para HEXA}
function TDecBinHex.AddToDec(Num1,Num2:String; Tipo1,Tipo2:Char):String;
var
  Resultado:Extended;
begin
  VerCreado;
  Tipo1:=UpCase(Tipo1);
  if (Tipo1='B') then
    Num1:=BinToDec(Num1)
  else
  if (Tipo1='H') then
    Num1:=HexToDec(Num1);
  Tipo2:=UpCase(Tipo2);
  if (Tipo2='B') then
    Num2:=BinToDec(Num2)
  else
  if (Tipo2='H') then
    Num2:=HexToDec(Num2);
  Resultado:=StrToFloat(Num1)+StrToFloat(Num2);
  Result:=FloatToStr(Resultado);
end;

{Recibe 2 numeros de cualquier tipo cada uno, los suma y los devuelve como BIN}
{En Tipo1 y Tipo2 debe recibir "D" para decimales, "B" para binarios y "H" para HEXA}
function TDecBinHex.AddToBin(Num1,Num2:String; Tipo1,Tipo2:Char):String;
var
  Aux:String;
  Resultado:Extended;
begin
  VerCreado;
  Tipo1:=UpCase(Tipo1);
  if (Tipo1='B') then
    Num1:=BinToDec(Num1)
  else
  if (Tipo1='H') then
    Num1:=HexToDec(Num1);
  Tipo2:=UpCase(Tipo2);
  if (Tipo2='B') then
    Num2:=BinToDec(Num2)
  else
  if (Tipo2='H') then
    Num2:=HexToDec(Num2);
  Resultado:=StrToFloat(Num1)+StrToFloat(Num2);
  Aux:=FloatToStr(Resultado);
  Result:=DecToBin(Aux);
end;

{Recibe 2 numeros de cualquier tipo cada uno, los suma y los devuelve como HEXA}
{En Tipo1 y Tipo2 debe recibir "D" para decimales, "B" para binarios y "H" para HEXA}
function TDecBinHex.AddToHex(Num1,Num2:String; Tipo1,Tipo2:Char):String;
var
  Aux:String;
  Resultado:Extended;
begin
  VerCreado;
  Tipo1:=UpCase(Tipo1);
  if (Tipo1='B') then
    Num1:=BinToDec(Num1)
  else
  if (Tipo1='H') then
    Num1:=HexToDec(Num1);
  Tipo2:=UpCase(Tipo2);
  if (Tipo2='B') then
    Num2:=BinToDec(Num2)
  else
  if (Tipo2='H') then
    Num2:=HexToDec(Num2);
  Resultado:=StrToFloat(Num1)+StrToFloat(Num2);
  Aux:=FloatToStr(Resultado);
  Result:=DecToHex(Aux);
end;


{-------------------------------RESTA-----------------------------}

{Recibe 2 numeros de cualquier tipo cada uno, los resta y los devuelve como DEC}
{En Tipo1 y Tipo2 debe recibir "D" para decimales, "B" para binarios y "H" para HEXA}
function TDecBinHex.SubToDec(Num1,Num2:String; Tipo1,Tipo2:Char):String;
var
  Aux:String;
  Resultado:Extended;
begin
  VerCreado;
  Tipo1:=UpCase(Tipo1);
  if (Tipo1='B') then
    Num1:=BinToDec(Num1)
  else
  if (Tipo1='H') then
    Num1:=HexToDec(Num1);
  Tipo2:=UpCase(Tipo2);
  if (Tipo2='B') then
    Num2:=BinToDec(Num2)
  else
  if (Tipo2='H') then
    Num2:=HexToDec(Num2);
  Resultado:=StrToFloat(Num1)-StrToFloat(Num2);
  Result:=FloatToStr(Resultado);
end;

{Recibe 2 numeros de cualquier tipo cada uno, los resta y los devuelve como BIN}
{En Tipo1 y Tipo2 debe recibir "D" para decimales, "B" para binarios y "H" para HEXA}
function TDecBinHex.SubToBin(Num1,Num2:String; Tipo1,Tipo2:Char):String;
var
  Aux:String;
  Resultado:Extended;
begin
  VerCreado;
  Tipo1:=UpCase(Tipo1);
  if (Tipo1='B') then
    Num1:=BinToDec(Num1)
  else
  if (Tipo1='H') then
    Num1:=HexToDec(Num1);
  Tipo2:=UpCase(Tipo2);
  if (Tipo2='B') then
    Num2:=BinToDec(Num2)
  else
  if (Tipo2='H') then
    Num2:=HexToDec(Num2);
  Resultado:=StrToFloat(Num1)-StrToFloat(Num2);
  Aux:=FloatToStr(Resultado);
  Result:=DecToBin(Aux);
end;

{Recibe 2 numeros de cualquier tipo cada uno, los resta y los devuelve como HEXA}
{En Tipo1 y Tipo2 debe recibir "D" para decimales, "B" para binarios y "H" para HEXA}
function TDecBinHex.SubToHex(Num1,Num2:String; Tipo1,Tipo2:Char):String;
var
  Aux:String;
  Resultado:Extended;
begin
  VerCreado;
  Tipo1:=UpCase(Tipo1);
  if (Tipo1='B') then
    Num1:=BinToDec(Num1)
  else
  if (Tipo1='H') then
    Num1:=HexToDec(Num1);
  Tipo2:=UpCase(Tipo2);
  if (Tipo2='B') then
    Num2:=BinToDec(Num2)
  else
  if (Tipo2='H') then
    Num2:=HexToDec(Num2);
  Resultado:=StrToFloat(Num1)-StrToFloat(Num2);
  Aux:=FloatToStr(Resultado);
  Result:=DecToHex(Aux);
end;


{--------------------------MULTIPLICACION-------------------------}

{Recibe 2 numeros de cualquier tipo cada uno, los multiplica y los devuelve como DEC}
{En Tipo1 y Tipo2 debe recibir "D" para decimales, "B" para binarios y "H" para HEXA}
function TDecBinHex.MultToDec(Num1,Num2:String; Tipo1,Tipo2:Char):String;
var
  Aux:String;
  Resultado:Extended;
begin
  VerCreado;
  Aux:=TipoNumero(Num1);
  Tipo1:=UpCase(Tipo1);
  if (Tipo1='B') then
    Num1:=BinToDec(Num1)
  else
  if (Tipo1='H') then
    Num1:=HexToDec(Num1);
  Tipo2:=UpCase(Tipo2);
  if (Tipo2='B') then
    Num2:=BinToDec(Num2)
  else
  if (Tipo2='H') then
    Num2:=HexToDec(Num2);
  Resultado:=StrToFloat(Num1)*StrToFloat(Num2);
  Result:=FloatToStr(Resultado);
end;

{Recibe 2 numeros de cualquier tipo cada uno, los multiplica y los devuelve como BIN}
{En Tipo1 y Tipo2 debe recibir "D" para decimales, "B" para binarios y "H" para HEXA}
function TDecBinHex.MultToBin(Num1,Num2:String; Tipo1,Tipo2:Char):String;
var
  Aux:String;
  Resultado:Extended;
begin
  VerCreado;
  Tipo1:=UpCase(Tipo1);
  if (Tipo1='B') then
    Num1:=BinToDec(Num1)
  else
  if (Tipo1='H') then
    Num1:=HexToDec(Num1);
  Tipo2:=UpCase(Tipo2);
  if (Tipo2='B') then
    Num2:=BinToDec(Num2)
  else
  if (Tipo2='H') then
    Num2:=HexToDec(Num2);
  Resultado:=StrToFloat(Num1)*StrToFloat(Num2);
  Aux:=FloatToStr(Resultado);
  Result:=DecToBin(Aux);
end;

{Recibe 2 numeros de cualquier tipo cada uno, los multiplica y los devuelve como HEXA}
{En Tipo1 y Tipo2 debe recibir "D" para decimales, "B" para binarios y "H" para HEXA}
function TDecBinHex.MultToHex(Num1,Num2:String; Tipo1,Tipo2:Char):String;
var
  Aux:String;
  Resultado:Extended;
begin
  VerCreado;
  Tipo1:=UpCase(Tipo1);
  if (Tipo1='B') then
    Num1:=BinToDec(Num1)
  else
  if (Tipo1='H') then
    Num1:=HexToDec(Num1);
  Tipo2:=UpCase(Tipo2);
  if (Tipo2='B') then
    Num2:=BinToDec(Num2)
  else
  if (Tipo2='H') then
    Num2:=HexToDec(Num2);
  Resultado:=StrToFloat(Num1)*StrToFloat(Num2);
  Aux:=FloatToStr(Resultado);
  Result:=DecToHex(Aux);
end;


{-----------------------------DIVISION----------------------------}

{Recibe 2 numeros de cualquier tipo cada uno, los divide y los devuelve como DEC}
{En Tipo1 y Tipo2 debe recibir "D" para decimales, "B" para binarios y "H" para HEXA}
function TDecBinHex.DivToDec(Num1,Num2:String; Tipo1,Tipo2:Char):String;
var
  Aux:String;
  Resultado:Extended;
begin
  VerCreado;
  Tipo1:=UpCase(Tipo1);
  if (Tipo1='B') then
    Num1:=BinToDec(Num1)
  else
  if (Tipo1='H') then
    Num1:=HexToDec(Num1);
  Tipo2:=UpCase(Tipo2);
  if (Tipo2='B') then
    Num2:=BinToDec(Num2)
  else
  if (Tipo2='H') then
    Num2:=HexToDec(Num2);
  Resultado:=StrToFloat(Num1)/StrToFloat(Num2);
  Result:=FloatToStr(Resultado);
end;

{Recibe 2 numeros de cualquier tipo cada uno, los divide y los devuelve como BIN}
{En Tipo1 y Tipo2 debe recibir "D" para decimales, "B" para binarios y "H" para HEXA}
function TDecBinHex.DivToBin(Num1,Num2:String; Tipo1,Tipo2:Char):String;
var
  Aux:String;
  Resultado:Extended;
begin
  VerCreado;
  Tipo1:=UpCase(Tipo1);
  if (Tipo1='B') then
    Num1:=BinToDec(Num1)
  else
  if (Tipo1='H') then
    Num1:=HexToDec(Num1);
  Tipo2:=UpCase(Tipo2);
  if (Tipo2='B') then
    Num2:=BinToDec(Num2)
  else
  if (Tipo2='H') then
    Num2:=HexToDec(Num2);
  Resultado:=StrToFloat(Num1)/StrToFloat(Num2);
  Aux:=FloatToStr(Resultado);
  Result:=DecToBin(Aux);
end;

{Recibe 2 numeros de cualquier tipo cada uno, los divide y los devuelve como HEXA}
{En Tipo1 y Tipo2 debe recibir "D" para decimales, "B" para binarios y "H" para HEXA}
function TDecBinHex.DivToHex(Num1,Num2:String; Tipo1,Tipo2:Char):String;
var
  Aux:String;
  Resultado:Extended;
begin
  VerCreado;
  Tipo1:=UpCase(Tipo1);
  if (Tipo1='B') then
    Num1:=BinToDec(Num1)
  else
  if (Tipo1='H') then
    Num1:=HexToDec(Num1);
  Tipo2:=UpCase(Tipo2);
  if (Tipo2='B') then
    Num2:=BinToDec(Num2)
  else
  if (Tipo2='H') then
    Num2:=HexToDec(Num2);
  Resultado:=StrToFloat(Num1)/StrToFloat(Num2);
  Aux:=FloatToStr(Resultado);
  Result:=DecToHex(Aux);
end;

end.
